<?php
/**
 *
 * @file
 * Contains \Drupal\simple_document\Controller\DocumentController
 *
 */

namespace Drupal\document_version\Controller;

use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\HttpFoundation\BinaryFileResponse;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;

class DocumentController extends ControllerBase {
  
  /**
   * Method to download a document
   *
   * @param string|null $bundle
   * @param string|null $document
   *
   * @return mixed
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   */
  public function serve($bundle = NULL, $document = NULL) {
    
    if ($bundle === NULL || $document === NULL) {
      throw new NotFoundHttpException();
    }
    
    $standard_document_t_alias = $document;
    // loading
    $doc_term = \Drupal::entityTypeManager()
      ->getStorage('taxonomy_term')
      ->loadByProperties([
        'vid' => 'standard_document_type',
        'field_simple_document_url' => $standard_document_t_alias,
      ]);
    $doc_term = array_pop($doc_term);
    
    
  
    // taxonomy term not found and so therefore does not exist
    if ($doc_term === null) {
      throw new NotFoundHttpException();
    }
    // loading
    /**
     * @var \Drupal\document_version\DocumentManager $document_manager
     */
    $document_manager = \Drupal::service('document_version.manager');
    $document = $document_manager->loadFromGroups($bundle, $doc_term->id());
    /**
     * @todo add in new way of getting simple document
     */
    if ($document === null) {
      throw new NotFoundHttpException();
    }
    // loading file information for download
    /**
     * @var \Drupal\file\Entity\File $file
     */
    $file = $document->get('file')->entity;
    $file_uri = $file->getFileUri();
    $mime_type = $file->getMimeType();
    $file_extension = pathinfo($file_uri, PATHINFO_EXTENSION);
    
    $fn = $doc_term->get('field_simple_document_url')[0]->value;
    $filename = $fn . '.' . $file_extension;
    
    // final check of existence of file
    if (!file_exists($file_uri)) {
      throw new NotFoundHttpException();
    }
    $headers = [
      'Content-Type' => $mime_type,
      'Content-Description' => 'inline',
      'Content-Disposition' => 'inline; filename=' . $filename,
      'Cache-Control' => 'no-store'
    ];
    
    // Return and trigger file donwload.
    return new BinaryFileResponse($file_uri, 200, $headers, TRUE);
    
  }
  
}
