<?php
/**
 * Created by PhpStorm.
 * User: pub
 * Date: 2019-08-16
 * Time: 11:56
 */

namespace Drupal\document_version;

use Drupal\document_version\Entity\DocumentEntityInterface;

/**
 * Provides an interface for defining Simple Document entities.
 *
 * @ingroup simple_document
 */
interface DocumentManagerInterface {
  
  /**
   * gets the active simple document
   *
   * @param \Drupal\document_version\Entity\DocumentEntityInterface $entity
   *
   * @return \Drupal\document_version\Entity\DocumentEntityInterface
   */
  public function getActive(DocumentEntityInterface $entity);
  
  /**
   * gets simple documents dated in the future
   *
   * @param \Drupal\document_version\Entity\DocumentEntityInterface $entity
   *
   * @return \Drupal\simple_document\Entity\SimpleDocument []
   */
  public function getFutureDocuments(DocumentEntityInterface $entity);
  
  /**
   * gets simple documents in the past
   *
   * @param \Drupal\document_version\Entity\DocumentEntityInterface $entity
   *
   * @return \Drupal\document_version\Entity\DocumentEntityInterface []
   */
  public function getPastDocuments(DocumentEntityInterface $entity);
  
  /**
   * gets simple documents in the past
   *
   * @param \Drupal\document_version\Entity\DocumentEntityInterface $entity
   *
   * @return \Drupal\document_version\Entity\DocumentEntityInterface []
   */
  public function getAllDocuments(DocumentEntityInterface $entity);
  
  /**
   * gets the active simple document given a document bundle and document_type_tid
   *
   * @param string $bundle
   * @param int $document_type_tid
   *
   * @return \Drupal\document_version\Entity\DocumentEntityInterface
   */
  public function loadFromGroups($bundle, $document_type_tid);
  
  /**
   * @param \Drupal\document_version\Entity\DocumentEntityInterface $entity
   *
   * @return bool
   */
  public function isActive(DocumentEntityInterface $entity);
  
  /**
   * returns a url slug
   * @param string $str
   *
   * @return string
   */
  public function slug($str);
}
