<?php

namespace Drupal\document_version\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class DocumentEntitySettingsForm.
 *
 * @ingroup document_version
 */
class DocumentEntitySettingsForm extends ConfigFormBase {

  /**
   * Returns a unique string identifying the form.
   *
   * @return string
   *   The unique string identifying the form.
   */
  public function getFormId() {
    return 'documententity_settings';
  }

  /**
   * Form submission handler.
   *
   * @param array $form
   *   An associative array containing the structure of the form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current state of the form.
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Empty implementation of the abstract submit class.
    return parent::submitForm($form, $form_state);
  }

  /**
   * Defines the settings form for Document entity entities.
   *
   * @param array $form
   *   An associative array containing the structure of the form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current state of the form.
   *
   * @return array
   *   Form definition array.
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    
    $config = $this->config('document_version.settings');
  
    $form['documententity_settings']['#markup'] = 'Settings form for Document entity entities. Manage field settings here.';
    $form['document_base_path'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Base Path for Documents'),
      '#description' => $this->t('Enter the base path for Documents'),
      '#default_value' => $config->get('document_base_path')
    ];
    return parent::buildForm($form, $form_state);
  }
  
  /**
   * Gets the configuration names that will be editable.
   *
   * @return array
   *   An array of configuration object names that are editable if called in
   *   conjunction with the trait's config() method.
   */
  protected function getEditableConfigNames() {
    return [
      'document_version.settings'
    ];
  }
}
