<?php

namespace Drupal\document_version\Plugin\Block;

use DateTimeZone;
use Drupal\Core\Block\BlockBase;
use Drupal\Core\Datetime\DrupalDateTime;
use Drupal\Core\Render\Element\Date;

/**
 * Provides a 'Current Time form' block.
 *
 * @Block(
 *   id = "document_version_current_time_block",
 *   admin_label = @Translation("Document Server Current Time"),
 *   category = @Translation("Document Version")
 * )
 */
class DocumentCurrentTimeBlock extends BlockBase {
  
  /**
   * Builds and returns the renderable array for this block plugin.
   *
   * If a block should not be rendered because it has no content, then this
   * method must also ensure to return no content: it must then only return an
   * empty array, or an empty array with #cache set (with cacheability metadata
   * indicating the circumstances for it being empty).
   *
   * @return array
   *   A renderable array representing the content of the block.
   *
   * @see \Drupal\block\BlockViewBuilder
   */
  public function build() {
    
    $current_time = new DrupalDateTime();
    $timezone = new DateTimeZone(date_default_timezone_get());
    $current_time->setTimezone($timezone);
    
    $local_time = \Drupal::service('date.formatter')->format($current_time->getTimestamp());
    $utc_time = new DrupalDateTime('now', new DateTimeZone('UTC'));
    $utc_time = \Drupal::service('date.formatter')->format($utc_time->getTimestamp());
    
    return [
      '#markup' => '<p>The current server time is: ' . $local_time . '</p>' .
        '<p>The current UTC time is: </p>' . $utc_time . '</p>'
    ];
  }
}
